%****************************
% schwartz-christofell model
%****************************
%Made by Davide Padoan- Universitat Politecnica de Catalunya/ Politecnico
%di Torino
%calculate the field distribution in a confiiguration electrode
%short-plane following the equations explicated in Appl. Phys Letts ,
%92, 173902(2008) by T.SUn, N.G. Green H.Morgan de la Universidad de
%Southampton

%DATOS
clear all;
h=10e-2;%it's the double of the distance needle-plane 
h1=8e-2;
h2=12e-2;
w1=0.1e-3;
d11=4.995e-2;
d21=4.995e-2;
w2=0.5e-3;
d12=4.975e-2;
d22=4.975e-2;
w=0.3e-3;%width of the needle(diameter)
d1=4.985e-2;%half distance end to end edge of flat plate collector to ground
d2=4.985e-2;%the same but on the other side
V=10000;%potential applied at the needle, the plane is the ground
D=360e-9;%diameter of the particle
R=D/2;%radius of the particle
epsilon_vacuum=8.854187817e-12; %vacuum permittivity
epsilon_polystyrene=2.65*epsilon_vacuum;%polystirene permittivity
epsilon_air=1.00058986*epsilon_vacuum;%air permittivity

dist_max=20*R;%distance between particles
dist_10=10*R;%distance between particles



%complex plane T, every values are in the real axis
TA=0;
TB=1;
TC=1.0009;

eq1=h/(2*(d1+w+d2));

%Hilberg's approximation
if eq1>=1
    M= (0.25*exp(h*pi/(2*(d1+d2+w))));
    k1= (M-1)/(M+1);
    
else
    M= 0.25*exp(2*pi*(d1+d2+w)/h);
    k1= sqrt(1-((M-1)/(M+1))^2);
end
m=k1^2;
TF= (TB*(TC-TA)*k1^2-TA*(TC-TB))/((TC-TA)*k1^2-(TC-TB));
Kk=ellipke(m); %complete elliptical integral K(k1)


C3=h/(2*Kk);

a=0+1i*d2/C3;

[Sni,Cni,Dni]=ellipji(a,m,0.01); %call the ellipji.m file that give the 
                                 %three elliptical functions, we needs only 
                                 %sn and cn

b=0+ 1i*(w+d2)/C3;
[Snibis ,Cnibis,Dnibis]=ellipji(b,m,0.01);

TE= TF*TC*Cni^2/(TC-TF*Sni^2);
TD=TF*TC*Cnibis^2/(TC-TF*Snibis^2);

k2=sqrt((TE-TD)*(TF-TC)/((TF-TD)*(TE-TC)));
k2prima=sqrt(1-k2^2);
m2=k2prima^2;
Kk2prima=ellipke(m2);

field=2*V/h;



Zx=linspace(0,5e-2,100);
Zy=linspace(0,(d1+d2+w),100);



z=1;
while(z<=100)
    c=1;
    while (c<=100)
        Z=Zx(c)+1i*Zy(z);
        [SnT(c,z),CnT(c,z),DnT(c,z)]=ellipji(Z/C3,m,0.00000000001);
        T(c,z)=(TF*TC*(CnT(c,z))^2)/(TC-TF*(SnT(c,z))^2);
        E_0(c,z)=(conj(1i*(2*V/h)*(Kk/Kk2prima)*((TF-TD)^(0.5)*...
        (TE-TC)^(0.5)/((TF-TB)^(0.5)*(TC-TA)^(0.5)))*((T(c,z)-TB)^(0.5)*...
        (T(c,z)-TA)^(0.5)/((T(c,z)-TD)^(0.5)*(T(c,z)-TE)^(0.5)))));
        c=c+1;
    end
    z=z+1;
end

eqh1=h1/(2*(d1+w+d2));

%Hilberg's approximation
if eqh1>=1
    M= (0.25*exp(h1*pi/(2*(d1+d2+w))));
    k1= (M-1)/(M+1);
    
else
    M= 0.25*exp(2*pi*(d1+d2+w)/h1);
    k1= sqrt(1-((M-1)/(M+1))^2);
end
m=k1^2;
TF= (TB*(TC-TA)*k1^2-TA*(TC-TB))/((TC-TA)*k1^2-(TC-TB));
Kk=ellipke(m); %complete elliptical integral K(k1)


C3=h1/(2*Kk);

a=0+1i*d2/C3;

[Sni,Cni,Dni]=ellipji(a,m,0.01); %call the ellipji.m file that give the 
                                 %three elliptical functions, we needs only 
                                 %sn and cn

b=0+ 1i*(w+d2)/C3;
[Snibis ,Cnibis,Dnibis]=ellipji(b,m,0.01);

TE= TF*TC*Cni^2/(TC-TF*Sni^2);
TD=TF*TC*Cnibis^2/(TC-TF*Snibis^2);

k2=sqrt((TE-TD)*(TF-TC)/((TF-TD)*(TE-TC)));
k2prima=sqrt(1-k2^2);
m2=k2prima^2;
Kk2prima=ellipke(m2);

field=2*V/h1;

Zxh1=linspace(0,4e-2,100);



z=1;
while(z<=100)
    c=1;
    while (c<=100)
        Z=Zxh1(c)+1i*Zy(z);
        [SnT(c,z),CnT(c,z),DnT(c,z)]=ellipji(Z/C3,m,0.00000000001);
        T(c,z)=(TF*TC*(CnT(c,z))^2)/(TC-TF*(SnT(c,z))^2);
        E_0h1(c,z)=(conj(1i*(2*V/h1)*(Kk/Kk2prima)*((TF-TD)^(0.5)*...
        (TE-TC)^(0.5)/((TF-TB)^(0.5)*(TC-TA)^(0.5)))*((T(c,z)-TB)^(0.5)*...
        (T(c,z)-TA)^(0.5)/((T(c,z)-TD)^(0.5)*(T(c,z)-TE)^(0.5)))));
        c=c+1;
    end
    z=z+1;
end

eqh21=h2/(2*(d1+w+d2));

%Hilberg's approximation
if eqh21>=1
    M= (0.25*exp(h2*pi/(2*(d1+d2+w))));
    k1= (M-1)/(M+1);
    
else
    M= 0.25*exp(2*pi*(d1+d2+w)/h2);
    k1= sqrt(1-((M-1)/(M+1))^2);
end
m=k1^2;
TF= (TB*(TC-TA)*k1^2-TA*(TC-TB))/((TC-TA)*k1^2-(TC-TB));
Kk=ellipke(m); %complete elliptical integral K(k1)


C3=h2/(2*Kk);

a=0+1i*d2/C3;

[Sni,Cni,Dni]=ellipji(a,m,0.01); %call the ellipji.m file that give the 
                                 %three elliptical functions, we needs only 
                                 %sn and cn

b=0+ 1i*(w+d2)/C3;
[Snibis ,Cnibis,Dnibis]=ellipji(b,m,0.01);

TE= TF*TC*Cni^2/(TC-TF*Sni^2);
TD=TF*TC*Cnibis^2/(TC-TF*Snibis^2);

k2=sqrt((TE-TD)*(TF-TC)/((TF-TD)*(TE-TC)));
k2prima=sqrt(1-k2^2);
m2=k2prima^2;
Kk2prima=ellipke(m2);

field=2*V/h2;

Zxh2=linspace(0,6e-2,100);




z=1;
while(z<=100)
    c=1;
    while (c<=100)
        Z=Zxh2(c)+1i*Zy(z);
        [SnT(c,z),CnT(c,z),DnT(c,z)]=ellipji(Z/C3,m,0.00000000001);
        T(c,z)=(TF*TC*(CnT(c,z))^2)/(TC-TF*(SnT(c,z))^2);
        E_0h2(c,z)=(conj(1i*(2*V/h2)*(Kk/Kk2prima)*((TF-TD)^(0.5)*...
        (TE-TC)^(0.5)/((TF-TB)^(0.5)*(TC-TA)^(0.5)))*((T(c,z)-TB)^(0.5)*...
        (T(c,z)-TA)^(0.5)/((T(c,z)-TD)^(0.5)*(T(c,z)-TE)^(0.5)))));
        c=c+1;
    end
    z=z+1;
end

eqw11=h/(2*(d11+w1+d21));

%Hilberg's approximation
if eqw11>=1
    M= (0.25*exp(h*pi/(2*(d11+d21+w1))));
    k1= (M-1)/(M+1);
    
else
    M= 0.25*exp(2*pi*(d11+d21+w1)/h);
    k1= sqrt(1-((M-1)/(M+1))^2);
end
m=k1^2;
TF= (TB*(TC-TA)*k1^2-TA*(TC-TB))/((TC-TA)*k1^2-(TC-TB));
Kk=ellipke(m); %complete elliptical integral K(k1)


C3=h/(2*Kk);

a=0+1i*d21/C3;

[Sni,Cni,Dni]=ellipji(a,m,0.01); %call the ellipji.m file that give the 
                                 %three elliptical functions, we needs only 
                                 %sn and cn

b=0+ 1i*(w1+d21)/C3;
[Snibis ,Cnibis,Dnibis]=ellipji(b,m,0.01);

TE= TF*TC*Cni^2/(TC-TF*Sni^2);
TD=TF*TC*Cnibis^2/(TC-TF*Snibis^2);

k2=sqrt((TE-TD)*(TF-TC)/((TF-TD)*(TE-TC)));
k2prima=sqrt(1-k2^2);
m2=k2prima^2;
Kk2prima=ellipke(m2);

field=2*V/h;



Zx=linspace(0,5e-2,100);
Zy1=linspace(0,(d11+d21+w1),100);



z=1;
while(z<=100)
    c=1;
    while (c<=100)
        Z=Zx(c)+1i*Zy(z);
        [SnT(c,z),CnT(c,z),DnT(c,z)]=ellipji(Z/C3,m,0.00000000001);
        T(c,z)=(TF*TC*(CnT(c,z))^2)/(TC-TF*(SnT(c,z))^2);
        E_0w1(c,z)=(conj(1i*(2*V/h)*(Kk/Kk2prima)*((TF-TD)^(0.5)*...
        (TE-TC)^(0.5)/((TF-TB)^(0.5)*(TC-TA)^(0.5)))*((T(c,z)-TB)^(0.5)*...
        (T(c,z)-TA)^(0.5)/((T(c,z)-TD)^(0.5)*(T(c,z)-TE)^(0.5)))));
        c=c+1;
    end
    z=z+1;
end

eqw21=h/(2*(d12+w2+d22));

%Hilberg's approximation
if eqw21>=1
    M= (0.25*exp(h*pi/(2*(d12+d22+w2))));
    k1= (M-1)/(M+1);
    
else
    M= 0.25*exp(2*pi*(d12+d22+w2)/h);
    k1= sqrt(1-((M-1)/(M+1))^2);
end
m=k1^2;
TF= (TB*(TC-TA)*k1^2-TA*(TC-TB))/((TC-TA)*k1^2-(TC-TB));
Kk=ellipke(m); %complete elliptical integral K(k1)


C3=h/(2*Kk);

a=0+1i*d22/C3;

[Sni,Cni,Dni]=ellipji(a,m,0.01); %call the ellipji.m file that give the 
                                 %three elliptical functions, we needs only 
                                 %sn and cn

b=0+ 1i*(w2+d22)/C3;
[Snibis ,Cnibis,Dnibis]=ellipji(b,m,0.01);

TE= TF*TC*Cni^2/(TC-TF*Sni^2);
TD=TF*TC*Cnibis^2/(TC-TF*Snibis^2);

k2=sqrt((TE-TD)*(TF-TC)/((TF-TD)*(TE-TC)));
k2prima=sqrt(1-k2^2);
m2=k2prima^2;
Kk2prima=ellipke(m2);

field=2*V/h;



Zx=linspace(0,5e-2,100);
Zy2=linspace(0,(d12+d22+w2),100);



z=1;
while(z<=100)
    c=1;
    while (c<=100)
        Z=Zx(c)+1i*Zy(z);
        [SnT(c,z),CnT(c,z),DnT(c,z)]=ellipji(Z/C3,m,0.00000000001);
        T(c,z)=(TF*TC*(CnT(c,z))^2)/(TC-TF*(SnT(c,z))^2);
        E_0w2(c,z)=(conj(1i*(2*V/h)*(Kk/Kk2prima)*((TF-TD)^(0.5)*...
        (TE-TC)^(0.5)/((TF-TB)^(0.5)*(TC-TA)^(0.5)))*((T(c,z)-TB)^(0.5)*...
        (T(c,z)-TA)^(0.5)/((T(c,z)-TD)^(0.5)*(T(c,z)-TE)^(0.5)))));
        c=c+1;
    end
    z=z+1;
end

figure(20)
plot(Zy,abs(E_0h1(62,:)),'-b',Zy,abs(E_0(50,:)),'-r',Zy,abs(E_0h2(42,:)),'-g');
legend('h=8cm','h=10cm','h=12cm')
title('Behaviour Electric Field with h variation (measured in 2.5 cm)');
xlabel('Distance(m)');
ylabel('Absolute Electric Field(V/m)');

figure(21)
plot(Zy,abs(E_0w1(50,:)),'-b',Zy,abs(E_0(50,:)),'-r',Zy,abs(E_0w2(50,:)),'-g');
legend('w=0.1mm','w=0.3mm','w=0.5mm')
title('Behaviour Electric Field with w variation (measured in 2.5 cm)');
xlabel('Distance(m)');
ylabel('Absolute Electric Field(V/m)');


EA=abs(E_0);
figure(1)
plot(Zy,EA(20,:),'-b',Zy,EA(30,:),'-g',Zy,EA(40,:),'-r',Zy,EA(50,:),'-m',...
Zy,EA(60,:),'-c',Zy,EA(70,:),'-y',Zy,EA(80,:),'-k');
legend('1 cm','1.5 cm', '2 cm','2.5 cm', '3 cm','3.5 cm','4 cm');
title('Absolute Electric Field of the system')
xlabel('Distance(m)')
ylabel('Absolute Electric Field(V/m)')

figure(17)
plot(Zx,EA(:,50),'-b');
legend('On the needle');
title('Absolute Electric Field of the system')
xlabel('Distance h(m)')
ylabel('Absolute Electric Field(V/m)')



figure(19)
plot(Zy,EA(1,:),'-b');
legend('0.05 cm');
title('Absolute Electric Field near the needle')
xlabel('Distance(m)')
ylabel('Absolute Electric Field(V/m)')

E_cone=EA(100,50);%electric field at 500um

[gradEx1,gradEy1]=gradient(EA);

[gradEx,gradEy]=gradient(EA^2);

%we change the sign of the equations because the Matlab's gradient no take
%care of that
c=1;
while c<=50
    gradEx1(:,c)=-gradEx1(:,c);
    gradEy1(:,c)=-gradEy1(:,c);
    gradEx(:,c)=-gradEx(:,c);
    gradEy(:,c)=-gradEy(:,c);
    c=c+1;
end;

figure(18)
plot(Zx,gradEx1(:,50),'-b');
legend('On the needle');
title('Electric Field gradient on the needle')
xlabel('Distance h(m)')
ylabel('Electric Field gradient(V/m)')


Fdepx=2*pi*epsilon_air*R^3*((epsilon_polystyrene-epsilon_air)/...
(epsilon_polystyrene+2*epsilon_air))*gradEx;
Fdepy=2*pi*epsilon_air*R^3*((epsilon_polystyrene-epsilon_air)/...
(epsilon_polystyrene+2*epsilon_air))*gradEy;

%taylor's cone and droplet charge

ro=1000;%Kg/m^3
Vagua=73e-3;
theta=43.5;
Utt=0.863*sqrt(Vagua*h/epsilon_vacuum);
Ut=0.6791*sqrt(0.02275*h/epsilon_vacuum);
flow_rate=6.1e-10;%m^3/s
rdrop=(ro/(4*pi^2*Vagua*tan(pi/2-theta)*((V/Ut)^2-1)))^(1/3)*...
      flow_rate^(2/3);
Q=8*pi*sqrt(epsilon_air*V*rdrop^3);
FA=Q*EA;
Fx=Q*real(E_0);
Fy=Q*imag(E_0);
Fdep=abs(Fdepx+1i*Fdepy);
figure(2)
plot(Zy,FA(50,:),'-b',Zy,FA(60,:),'-g',Zy,FA(70,:),'-r',...
Zy,FA(80,:),'-m',Zy,FA(90,:),'-c',Zy,FA(100,:),'-k')

title('Absolute Coulomb Force for a single particle')
legend('2.5 cm','3 cm','3.5 cm','4 cm','4.5 cm','5 cm');
xlabel('Distance(m)')
ylabel('Absolute Coulomb Force(N)')

figure(3)
plot(Zy,Fdep(70,:),'-b',Zy,Fdep(80,:),'-g',Zy,Fdep(90,:),'-r',...
    Zy,Fdep(100,:),'-k')
legend('3.5 cm','4 cm','4.5 cm','5 cm')
title('Absolute Dielectrophoretic Force for a single particle')
xlabel('Distance(m)')
ylabel('Absolute Dielectrophoretic Force(N)')

figure(15)
quiver(Zy,Zx,Fy,Fx)
title('Coulomb Forces direction');
xlabel('Distance(m)');
ylabel('Distance(m)');

figure(16)
quiver(Zy,Zx, Fdepy,Fdepx);
title('Dielectrophoretic Forces direction');
xlabel('Distance(m)');
ylabel('Distance(m)');

%-----
%calculation of force between two particles

rd=linspace(0,dist_10,26); %distance between two particles
r=linspace(0,dist_10,25);

alphad=linspace(0,pi/2,26); %angle between two particles
alpha=linspace(0,pi/2,25); 
k=(epsilon_polystyrene-epsilon_air)/...%Clausius Mossati Factor
(epsilon_polystyrene+2*epsilon_air);

z=1;
while(z<=25)
    c=1;
    while (c<=26)
        f_xt(c,z)=(1/D)/(sqrt(r(z)^2+(D^2)/4-r(z)*D*cos(alphad(c))))-...
            (1/D)/(sqrt(r(z)^2+(D^2)/4+r(z)*D*cos(alphad(c))));
        f_dr_xt(c,z)=-((2*r(z)-D*cos(alphad(c)))/(2*D*sqrt(r(z)^2+...
            (D^2)/4-r(z)*D*cos(alphad(c)))))/(r(z)^2+(D^2)/4-...
            r(z)*D*cos(alphad(c)))+((2*r(z)+D*cos(alphad(c)))/...
            (2*D*sqrt(r(z)^2+(D^2)/4+r(z)*D*cos(alphad(c)))))/...
            (r(z)^2+(D^2)/4+r(z)*D*cos(alphad(c)));
        c=c+1;
    end
    z=z+1;
end
z=1;
while(z<=26)
    c=1;
    while (c<=25)
        f_xr(c,z)=(1/D)/(sqrt(rd(z)^2+(D^2)/4-rd(z)*D*cos(alpha(c))))-...
            (1/D)/(sqrt(rd(z)^2+(D^2)/4+rd(z)*D*cos(alpha(c))));
        f_dr_xr(c,z)=-((2*rd(z)-D*cos(alpha(c)))/(2*D*sqrt(rd(z)^2+...
            (D^2)/4-rd(z)*D*cos(alpha(c)))))/(rd(z)^2+(D^2)/4-...
            rd(z)*D*cos(alpha(c)))+((2*rd(z)+D*cos(alpha(c)))/...
            (2*D*sqrt(rd(z)^2+(D^2)/4+rd(z)*D*cos(alpha(c)))))/...
            (rd(z)^2+(D^2)/4+rd(z)*D*cos(alpha(c)));
        c=c+1;
    end
    z=z+1;
end



c=1;
while (c<=26)
    Pb_xr(c,:)=4.*pi.*epsilon_vacuum.*R.*EA(100,50).*cos(alpha).*...
        (1./f_xr(:,c)'+ (cos(alpha)-(R.*cos(alpha).*...
        f_dr_xr(:,c)')./f_xr(:,c)')./(R.*cos(alpha).*f_dr_xr(:,c)'-...
        (epsilon_polystyrene./epsilon_air).*f_xr(:,c)'.*cos(alpha)));
    V_xr(c,:)=(Pb_xr(c,:)./(4.*pi.*epsilon_vacuum)).*f_xr(:,c)';
    c=c+1;
end;

c=1;
while (c<=25)
    E_r_t(:,c)=diff(V_xr(:,c))./(dist_10/25);%we have a change of the sign 
                                             %caused by the Matlab's 
                                             %derivation
    c=c+1;
end;

c=1;
while (c<=25)
    E_r(:,c)=(EA(100,50).*cos(alpha))' + E_r_t(c,:)';
    Pb_xt(c,:)=4.*pi.*epsilon_vacuum.*R.*EA(100,50).*cos(alphad).*...
        (1./f_xt(:,c)'+ (cos(alphad)-(R.*cos(alphad).*...
        f_dr_xt(:,c)')./f_xt(:,c)')./(R.*cos(alphad).*f_dr_xt(:,c)'-...
        (epsilon_polystyrene./epsilon_air).*f_xt(:,c)'.*cos(alphad)));
    V_xt(c,:)=(Pb_xt(c,:)./(4.*pi.*epsilon_vacuum)).*f_xt(:,c)';
    E_alpha_sin_r(c,:)=-diff(V_xt(c,:))./(pi/2/25);
    E_alpha(c,:)=-(EA(100,50).*sin(alpha))+E_alpha_sin_r(c,:)./r(c);
    c=c+1;
end;

E_abs=sqrt(E_r.^2+E_alpha'.^2);
[gradEr,gradEalpha]=gradient(E_abs.^2);
Fdepr=2.*pi.*epsilon_air.*R.^3.*k.*gradEr./(dist_10/25);
Fdepalpha=2.*pi.*epsilon_air.*R.^3.*k.*gradEalpha./(pi/2/25);

c=1;
while (c<=25)
    z=1;
    while (z<=25)
        if Fdepr(c,z)>0
            phi(c,z)=atan(Fdepalpha(c,z)/Fdepr(c,z));
        else
            phi(c,z)=atan(Fdepalpha(c,z)/Fdepr(c,z))+pi;
        end;
        z=z+1;
    end;
    c=c+1;
end;
asx=r(25).*sin(alpha);
asy=r(25).*cos(alpha);
Fx=sqrt(Fdepr(:,25)'.^2+Fdepalpha(:,25)'.^2).*cos((pi/2-alpha-phi(:,25)'));
Fy=sqrt(Fdepr(:,25)'.^2+Fdepalpha(:,25)'.^2).*sin((pi/2-alpha-phi(:,25)'));





figure(14)
quiver(asx,asy,Fx,Fy);
title('direction dielectroforetics forces two particles')

ylabel('eje y(m)')
xlabel('eje x(m)')

Fdepabs=sqrt(Fdepr.^2+Fdepalpha.^2);

alphag=alpha.*180/pi;
figure(4)
plot(alphag,E_r(:,25),'-k')
legend('r=10*R')
title('R Electric Field')
xlabel('theta(degrees)')
ylabel('Radial component of Electric Field(V/m)')
figure(5)
plot(alphag,E_alpha(25,:),'-k')
legend('r=10*R')
title('tangential component of Electric Field')
xlabel('theta(degrees)')
ylabel('Tangential component of Electric Field(V/m)')
figure(6)
plot(alphag,E_abs(:,25),'-k')
legend('r=10*R')
title('Modulus of Electric Field')
xlabel('theta(degrees)')
ylabel('Modulus of Electric Field(V/m)')
figure(7)
plot(alphag,Fdepr(:,25),'-k')
legend('r=10*R')
title('R Dielectrophoretic Force')
xlabel('theta(degrees)')
ylabel('R Dielectrophoretic Force(N)')
figure(8)
plot(alphag,Fdepalpha(:,25),'-k')
legend('r=10*R')
title('Theta Dielectrophoretic Force')
xlabel('theta(radius)')
ylabel('Theta Dielectrophoretic Force(N)')
figure(9)
plot(alphag,Fdepabs(:,25),'-k')
legend('r=10*R')
title('Absolute Dielectrophoretic Force')
xlabel('theta(degrees)')
ylabel('Absolute Dielectrophoretic Force(N)')
figure(10)
angle=(alpha'+(pi/2-phi(:,25))).*180/pi;
plot(alphag,angle,'-k')
title('phi angle')
xlabel('theta(degrees)')
ylabel('phi(degrees)')

%-----
%calculation forces between 3 to 1 (3D) with particle in the middle
%distance 20*R
alpha_min=atan(sqrt(3)/30);

alpha_max=atan(sqrt(3)/3);
alpha=linspace(alpha_min,alpha_max,25); %angle between two particles
alphad=linspace(alpha_min,alpha_max,26); %angle between two particles
alphadd=linspace(alpha_min,alpha_max,27); %angle between two particles
alphag=alpha.*180/pi;
R_cm=R*10^2; %Radius in cm
Volume_sphere=4/3*pi*R_cm^3;
dens=1.05; % density polystirene in g/cm^3
weight=Volume_sphere*dens/1000; %in kg
F_weight=weight*9.81;
c=1;
while (c<=25)
    r3g(c)=D*sqrt(3)/(3*sin(alpha(c)));%distance between spheres
    c=c+1;
end;
c=1;
while (c<=26)
    r3(c)=D*sqrt(3)/(3*sin(alphad(c)));%distance between spheres
    c=c+1;
end;
c=1;
while (c<=27)
    rd3(c)=D*sqrt(3)/(3*sin(alphadd(c)));%distance between spheres
    c=c+1;
end;
z=1;
while(z<=27)
    c=1;
    while (c<=27)
        if z==28-c
        f(c)=(1/D)/(sqrt(rd3(z)^2+(D^2)/4-rd3(z)*D*cos(alphadd(c))))-...
            (1/D)/(sqrt(rd3(z)^2+(D^2)/4+rd3(z)*D*cos(alphadd(c))));
        f_dr(c)=-((2*rd3(z)-D*cos(alphadd(c)))/(2*D*sqrt(rd3(z)^2+...
            (D^2)/4-rd3(z)*D*cos(alphadd(c)))))/(rd3(z)^2+(D^2)/4-...
            rd3(z)*D*cos(alphadd(c)))+((2*rd3(z)+D*cos(alphadd(c)))/...
            (2*D*sqrt(rd3(z)^2+(D^2)/4+rd3(z)*D*cos(alphadd(c)))))/...
            (rd3(z)^2+(D^2)/4+rd3(c)*D*cos(alphadd(c)));
        end;
        c=c+1;
    end
    z=z+1;
end


Pb=4.*pi.*epsilon_vacuum.*R.*EA(100,50).*cos(alphadd).*(1./f+...
    (cos(alphadd)-(R.*cos(alphadd).*f_dr)./f)./(R.*cos(alphadd).*f_dr-...
    (epsilon_polystyrene./epsilon_air).*f.*cos(alphadd)));
V=(Pb./(4.*pi.*epsilon_vacuum)).*f;
E_r_t=D.*cos(alphad).*sqrt(3)./(3.*sin(alphad).^2).*diff(V)./...
    (abs(alpha(25)-alpha(1))/25);
E_r3=(EA(100,50).*cos(alphad)) + E_r_t;
E_alpha_sin_r=-diff(V)./(abs(alpha(25)-alpha(1))/25);
E_alpha3=-(EA(100,50).*sin(alphad))+E_alpha_sin_r./r3;
E_abs3=sqrt(E_alpha3.^2+E_r3.^2);

gradEr3=-D.*cos(alpha).*sqrt(3)./(3.*sin(alpha).^2).*diff(E_abs3.^2)./...
    (abs(alpha(25)-alpha(1))/25);
gradEalpha3=diff(E_abs3.^2)./(abs(alpha(25)-alpha(1))/25);
Fdepalpha3=2*pi*epsilon_air*R^3*k*gradEalpha3;
Fdepr3=2*pi*epsilon_air*R^3*k*gradEr3;
Fdepabs3=sqrt(Fdepalpha3.^2+Fdepr3.^2);
c=1;
while (c<=25)
    if Fdepr3(c)>0
        phi3(c)=atan(Fdepalpha3(c)/Fdepr3(c));
    else
        phi3(c)=atan(Fdepalpha3(c)/Fdepr3(c))+pi;
    end;
    c=c+1;
end;
Fdepx=(-Fdepabs3.*sin(alpha)*cos(pi/6)+Fdepabs3.*sin(alpha)*...
    cos(pi/6)).*cos(pi/2-alpha+phi3);
Fdepy=(-Fdepabs3.*sin(alpha)*sin(pi/6)-Fdepabs3.*sin(alpha)*sin(pi/6)+...
    Fdepabs3.*sin(alpha)).*cos(pi/2-alpha+phi3);
Fdepz=(Fdepabs3.*cos(alpha)+Fdepabs3.*cos(alpha)+Fdepabs3.*cos(alpha)).*...
    sin(pi/2-alpha+phi3);
Fdep_dip_xy=Fdepabs3.*cos(pi/2-alpha+phi3);
Fdep_dip_z=Fdepabs3.*sin(pi/2-alpha+phi3);
alphag=alpha.*180./pi;

figure(11)
plot(r3g,Fdepx)
title('Absolute Dielectrophoretic Force in x')
xlabel('Distancia(m)')
ylabel('Absolute Dielectrophoretic Force in x(N)')

figure(12)
plot(r3g,Fdepy)
title('Absolute Dielectrophoretic Force in y')
xlabel('Distancia(m)') 
ylabel('Absolute Dielectrophoretic Force in y(N)')

figure(13)
plot(r3g,Fdepz)
title('Absolute Dielectrophoretic Force in z')
xlabel('Distancia(m)')
ylabel('Absolute Dielectrophoretic Force in z(N)')


%threshold electric field
k_b=1.3806488*10^(-23);%Boltzmann's constant
T=300;% Room temperature in Kelvin
Eth=1.7*R^(-3/2)*sqrt(k_b*T/epsilon_air)/k;





%1 to 3 with moving particle using Euler's angles
asse_x=1;
asse_y=2;
asse_z=3;
yaw=linspace(-pi/4,pi/4,12);%(psi)
pitch=linspace(-pi/4,pi/4,12);%(theta)
roll=linspace(-pi,pi,12);%(phi)
angolo=17; %5 

[Y, RO]=meshgrid(yaw,roll);

Fdep1=[-Fdep_dip_xy(angolo).*sin(alpha(angolo)).*cos(pi/6+pi/3);...
    -Fdep_dip_xy(angolo).*sin(alpha(angolo)).*sin(pi/6+pi/3);...
    Fdep_dip_z(angolo).*cos(alpha(angolo))];
Fdep2=[-Fdep_dip_xy(angolo).*sin(alpha(angolo)).*sin(pi/3);...
    Fdep_dip_xy(angolo).*sin(alpha(angolo)).*cos(pi/3);...
    Fdep_dip_z(angolo).*cos(alpha(angolo))];
Fdep3=[Fdep_dip_xy(angolo).*sin(alpha(angolo)).*cos(pi/3);...
    -Fdep_dip_xy(angolo).*sin(alpha(angolo)).*sin(pi/3);...
    Fdep_dip_z(angolo).*cos(alpha(angolo))];

F1x=Fdep1(asse_x);
F1y=Fdep1(asse_y);
F1z=Fdep1(asse_z);
F2x=Fdep2(asse_x);
F2y=Fdep2(asse_y);
F2z=Fdep2(asse_z);
F3x=Fdep3(asse_x);
F3y=Fdep3(asse_y);
F3z=Fdep3(asse_z);


[P, RO]=meshgrid(pitch,roll);
%cambio coordinate
k=1;
while k<=12
    l=1;
    while l<=12
        g=1;
        while g<=12
            Fdep1Ex(g,l,k)=((cos(yaw(g)).*cos(pitch(l)).*cos(roll(k))-...
                sin(yaw(g)).*sin(roll(k)))+...
                sin(yaw(g)).*cos(pitch(l)).*cos(roll(k))+...
                cos(yaw(g)).*sin(roll(k))-...
                sin(pitch(l)).*cos(roll(k))).*F1x;
            Fdep1Ey(g,l,k)=((-cos(yaw(g)).*cos(pitch(l)).*sin(roll(k))-...
                sin(yaw(g)).*cos(roll(k)))-...
                sin(yaw(g)).*cos(pitch(l)).*sin(roll(k))+...
                cos(yaw(g)).*cos(roll(k))+...
                sin(pitch(l)).*sin(roll(k))).*F1y;
            Fdep1Ez(g,l,k)=(cos(yaw(g)).*sin(pitch(l))+...
                sin(yaw(g)).*sin(pitch(l)) + cos(pitch(l))).*F1z;
            Fdep2Ex(g,l,k)=((cos(yaw(g)).*cos(pitch(l)).*cos(roll(k))-...
                sin(yaw(g)).*sin(roll(k)))+...
                sin(yaw(g)).*cos(pitch(l)).*cos(roll(k))+...
                cos(yaw(g)).*sin(roll(k))-...
                sin(pitch(l)).*cos(roll(k))).*F2x;
            Fdep2Ey(g,l,k)=((-cos(yaw(g)).*cos(pitch(l)).*sin(roll(k))-...
                sin(yaw(g)).*cos(roll(k)))-...
                sin(yaw(g)).*cos(pitch(l)).*sin(roll(k))+...
                cos(yaw(g)).*cos(roll(k))+...
                sin(pitch(l)).*sin(roll(k))).*F2y;
            Fdep2Ez(g,l,k)=(cos(yaw(g)).*sin(pitch(l))+...
                sin(yaw(g)).*sin(pitch(l)) + cos(pitch(l))).*F2z;
            Fdep3Ex(g,l,k)=((cos(yaw(g)).*cos(pitch(l)).*cos(roll(k))-...
                sin(yaw(g)).*sin(roll(k)))+...
                sin(yaw(g)).*cos(pitch(l)).*cos(roll(k))+...
                cos(yaw(g)).*sin(roll(k))-...
                sin(pitch(l)).*cos(roll(k))).*F3x;
            Fdep3Ey(g,l,k)=((-cos(yaw(g)).*cos(pitch(l)).*sin(roll(k))-...
                sin(yaw(g)).*cos(roll(k)))-...
                sin(yaw(g)).*cos(pitch(l)).*sin(roll(k))+...
                cos(yaw(g)).*cos(roll(k))+...
                sin(pitch(l)).*sin(roll(k))).*F3y;
            Fdep3Ez(g,l,k)=(cos(yaw(g)).*sin(pitch(l))+...
                sin(yaw(g)).*sin(pitch(l)) + cos(pitch(l))).*F3z;
            g=g+1;
        end;
        l=l+1;
    end;
    k=k+1;
end;



k=1;
while k<=12
    l=1;
    while l<=12
        g=1;
        while g<=12
            X=[(cos(yaw(g)).*cos(pitch(l)).*cos(roll(k))-...
                sin(yaw(g)).*sin(roll(k))),...
                sin(yaw(g)).*cos(pitch(l)).*cos(roll(k))+...
                cos(yaw(g)).*sin(roll(k)),-sin(pitch(l)).*cos(roll(k));
               (-cos(yaw(g)).*cos(pitch(l)).*sin(roll(k))-...
               sin(yaw(g)).*cos(roll(k))),...
               -sin(yaw(g)).*cos(pitch(l)).*sin(roll(k))+...
               cos(yaw(g)).*cos(roll(k)),+sin(pitch(l)).*sin(roll(k));
                cos(yaw(g)).*sin(pitch(l)),+sin(yaw(g)).*sin(pitch(l)),...
                + cos(pitch(l))]'*10*R;
            FdeptotEx(g,l,k)=Fdep1Ex(g,l,k)+Fdep2Ex(g,l,k)+Fdep3Ex(g,l,k);
            FdeptotEy(g,l,k)=Fdep1Ey(g,l,k)+Fdep2Ey(g,l,k)+Fdep3Ey(g,l,k);
            FdeptotEz(g,l,k)=Fdep1Ez(g,l,k)+Fdep2Ez(g,l,k)+Fdep3Ez(g,l,k);
            
            ejex(g,l,k)=X(1,1)+X(2,1)+X(3,1);
            ejey(g,l,k)=X(1,2)+X(2,2)+X(3,2);
            ejez(g,l,k)=X(1,3)+X(2,3)+X(3,3);
            g=g+1;
        end;
        l=l+1;
    end;
    k=k+1;
end;


figure(47)
quiver3(ejex,ejey,ejez,FdeptotEx,FdeptotEy,FdeptotEz);
title('Direction Dielectrophoretics Forces');

zlabel('eje z(m)');
ylabel('eje y(m)');
xlabel('eje x(m)');

